==> v4.3.0.tar.gz: recyclarr/README.md <==
# Recyclarr

[![MIT license](https://img.shields.io/badge/License-MIT-blue.svg)](https://github.com/recyclarr/recyclarr/blob/master/LICENSE)
[![Build & Test](https://github.com/recyclarr/recyclarr/actions/workflows/build.yml/badge.svg)](https://github.com/recyclarr/recyclarr/actions/workflows/build.yml)
[![Quality Gate Status](https://sonarcloud.io/api/project_badges/measure?project=recyclarr_recyclarr&metric=alert_status)](https://sonarcloud.io/summary/new_code?id=recyclarr_recyclarr)
[![GitHub release](https://img.shields.io/github/release/recyclarr/recyclarr.svg)](https://github.com/recyclarr/recyclarr/releases/)
[![Support Server](https://img.shields.io/discord/492590071455940612.svg?color=7289da&label=TRaSH-Guides&logo=discord&style=flat-square)](https://discord.com/invite/Vau8dZ3)

A command-line application that will automatically synchronize recommended settings from the [TRaSH
guides](https://trash-guides.info/) to your Sonarr/Radarr instances.

Formerly named "Trash Updater".

## Features

The following information can be synced to \*arr services from the TRaSH Guides. For a more detailed
features list, see the [Features] page.

[Features]: https://recyclarr.dev/wiki/features

**Sonarr**:

- Sync Release Profiles from the guide to Sonarr v3.
- Supports Sonarr v4 Custom Formats.
- Sync Quality Definitions (sizes) from the guide.
- Add Tags to Release Profiles.
- Assign scores from the guide to quality profiles.

**Radarr**:

- Sync Custom Formats from the guide.
- Sync Quality Definitions from the guide.
- Assign CF scores to quality profile (manual or use values from the guide).

### Read the Documentation

Main documentation is located in [the wiki](https://recyclarr.dev/wiki). Links provided below for
some main topics.

- [Installation](https://recyclarr.dev/wiki/installation/)
- [Command Line Reference](https://recyclarr.dev/wiki/reference/cli-reference)
- [Configuration Reference](https://recyclarr.dev/wiki/reference/config-reference)
- [Settings Reference](https://recyclarr.dev/wiki/reference/settings-reference)
- [Troubleshooting](https://recyclarr.dev/wiki/troubleshooting)

==> v5.0.0.tar.gz: recyclarr/README.md <==
# Recyclarr

[![MIT license](https://img.shields.io/badge/License-MIT-blue.svg)](https://github.com/recyclarr/recyclarr/blob/master/LICENSE)
[![Build & Test](https://github.com/recyclarr/recyclarr/actions/workflows/build.yml/badge.svg)](https://github.com/recyclarr/recyclarr/actions/workflows/build.yml)
[![Quality Gate Status](https://sonarcloud.io/api/project_badges/measure?project=recyclarr_recyclarr&metric=alert_status)](https://sonarcloud.io/summary/new_code?id=recyclarr_recyclarr)
[![GitHub release](https://img.shields.io/github/release/recyclarr/recyclarr.svg)](https://github.com/recyclarr/recyclarr/releases/)
[![Support Server](https://img.shields.io/discord/492590071455940612.svg?color=7289da&label=TRaSH-Guides&logo=discord&style=flat-square)](https://discord.com/invite/Vau8dZ3)

A command-line application that will automatically synchronize recommended settings from the [TRaSH
guides](https://trash-guides.info/) to your Sonarr/Radarr instances.

Formerly named "Trash Updater".

## Features

The following information can be synced to \*arr services from the TRaSH Guides. For a more detailed
features list, see the [Features] page.

[Features]: https://recyclarr.dev/wiki/features

**Sonarr**:

- Sync Release Profiles from the guide to Sonarr v3.
- Supports Sonarr v4 Custom Formats.
- Sync Quality Definitions (sizes) from the guide.
- Add Tags to Release Profiles.
- Assign scores from the guide to quality profiles.

**Radarr**:

- Sync Custom Formats from the guide.
- Sync Quality Definitions from the guide.
- Assign CF scores to quality profile (manual or use values from the guide).

### Read the Documentation

Main documentation is located in [the wiki](https://recyclarr.dev/wiki). Links provided below for
some main topics.

- [Installation](https://recyclarr.dev/wiki/installation/)
- [Command Line Reference](https://recyclarr.dev/wiki/cli/)
- [Configuration Reference](https://recyclarr.dev/wiki/yaml/config-reference)
- [Settings Reference](https://recyclarr.dev/wiki/yaml/settings-reference)
- [Troubleshooting](https://recyclarr.dev/wiki/troubleshooting/help)
